using LinearAlgebra
using Random
using Clustering
using LaTeXStrings
using Plots

include("readclassjson.jl")

data = readclassjson("impute_via_kmeans.json")
X_train = data["X_train"]
X_test = data["X_test"]

Random.seed!(0)
inds = rand([1,2],size(X_test,1))
X_test_missing = copy(X_test)

for i in 1:size(X_test,1)
    X_test_missing[i,inds[i]] = NaN
end

n, d = size(X_train)

function RMSE(Xhat, X)
    return sqrt(sum((Xhat-X).^2)/size(Xhat,1))
end

function fit_kmeans(X, k)
    Random.seed!(42)
    result = Clustering.kmeans(X', k)
    return result.centers
end

RMS_errors = []
ks = [5,10,15,20,25]
for k in ks
    # TODO: Fit a k-means data model and get the centers
    
    X_test_impute = copy(X_test_missing)
    
    # TODO: Impute the missing entries of X_test_impute using the data model
    
    push!(RMS_errors, RMSE(X_test_impute, X_test))
end

plot(ks, RMS_errors, legend=false, ylabel="Test RMSE", xlabel=L"$k$")
savefig("kmeans_rmse.pdf")

scatter(X_train[:,1], X_train[:,2], legend=true, color=:blue, label="Train data")
scatter!(X_test[:,1], X_test[:,2], color=:red, label="Test data")
savefig("kmeans_data.pdf")
